mocks

package
v0.0.0-...-01ad037 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Repository

type Repository struct {
	mock.Mock
}

Repository is an autogenerated mock type for the Repository type

func NewRepository

func NewRepository(t interface {
	mock.TestingT
	Cleanup(func())
}) *Repository

NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Repository) GetConfigFromPath

func (_m *Repository) GetConfigFromPath(baseDir string, filePath string) (*models.Config, error)

GetConfigFromPath provides a mock function with given fields: baseDir, filePath

func (*Repository) GetConfigFromURL

func (_m *Repository) GetConfigFromURL(url string) (*models.Config, error)

GetConfigFromURL provides a mock function with given fields: url

type Usecase

type Usecase struct {
	mock.Mock
}

Usecase is an autogenerated mock type for the Usecase type

func NewUsecase

func NewUsecase(t interface {
	mock.TestingT
	Cleanup(func())
}) *Usecase

NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Usecase) GetConfig

func (_m *Usecase) GetConfig(params *models.ConfigParams) *models.ConfigBag

GetConfig provides a mock function with given fields: params

func (*Usecase) GetConfigList

func (_m *Usecase) GetConfigList() []models.ConfigMetadata

GetConfigList provides a mock function with given fields:

func (*Usecase) Hydrate

func (_m *Usecase) Hydrate(_a0 *models.ConfigBag)

Hydrate provides a mock function with given fields: _a0

func (*Usecase) Verify

func (_m *Usecase) Verify(_a0 *models.ConfigBag)

Verify provides a mock function with given fields: _a0

Jump to