mocks

package
v0.0.0-...-01ad037 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Repository

type Repository struct {
	mock.Mock
}

Repository is an autogenerated mock type for the Repository type

func NewRepository

func NewRepository(t interface {
	mock.TestingT
	Cleanup(func())
}) *Repository

NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Repository) ExecutePing

func (_m *Repository) ExecutePing(hostname string) (*models.Ping, error)

ExecutePing provides a mock function with given fields: hostname

type Usecase

type Usecase struct {
	mock.Mock
}

Usecase is an autogenerated mock type for the Usecase type

func NewUsecase

func NewUsecase(t interface {
	mock.TestingT
	Cleanup(func())
}) *Usecase

NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Usecase) Ping

func (_m *Usecase) Ping(params *models.PingParams) (*monitorormodels.Tile, error)

Ping provides a mock function with given fields: params

Jump to