Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
Repository is an autogenerated mock type for the Repository type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) OpenSocket ¶
func (_m *Repository) OpenSocket(hostname string, port int) error
OpenSocket provides a mock function with given fields: hostname, port
type Usecase ¶
Usecase is an autogenerated mock type for the Usecase type
func NewUsecase ¶
NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Usecase) Port ¶
func (_m *Usecase) Port(params *models.PortParams) (*monitorormodels.Tile, error)
Port provides a mock function with given fields: params