package
Version:
v0.0.0-...-01ad037
Opens a new window with list of versions in this module.
Published: Aug 13, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BuildParams struct {
params.Default
Owner string `json:"owner" query:"owner" validate:"required"`
Repository string `json:"repository" query:"repository" validate:"required"`
Branch string `json:"branch" query:"branch" validate:"required"`
}
Used by cache as identifier
Source Files
¶
Click to show internal directories.
Click to hide internal directories.