package
Version:
v0.0.0-...-01ad037
Opens a new window with list of versions in this module.
Published: Aug 13, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var Default = &TravisCI{
URL: "https://api.travis-ci.com/",
Token: "",
GithubToken: "",
Timeout: 2000,
}
type TravisCI struct {
URL string `validate:"required,url,http"`
Token string
GithubToken string
Timeout int `validate:"gte=0"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.