mocks

package
v0.0.0-...-01ad037 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IssuesService

type IssuesService struct {
	mock.Mock
}

IssuesService is an autogenerated mock type for the IssuesService type

func NewIssuesService

func NewIssuesService(t interface {
	mock.TestingT
	Cleanup(func())
}) *IssuesService

NewIssuesService creates a new instance of IssuesService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*IssuesService) ListIssues

ListIssues provides a mock function with given fields: opt, options

func (*IssuesService) ListProjectIssues

func (_m *IssuesService) ListProjectIssues(pid interface{}, opt *gitlab.ListProjectIssuesOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.Issue, *gitlab.Response, error)

ListProjectIssues provides a mock function with given fields: pid, opt, options

type MergeRequestsService

type MergeRequestsService struct {
	mock.Mock
}

MergeRequestsService is an autogenerated mock type for the MergeRequestsService type

func NewMergeRequestsService

func NewMergeRequestsService(t interface {
	mock.TestingT
	Cleanup(func())
}) *MergeRequestsService

NewMergeRequestsService creates a new instance of MergeRequestsService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MergeRequestsService) GetMergeRequest

func (_m *MergeRequestsService) GetMergeRequest(pid interface{}, mergeRequest int, opt *gitlab.GetMergeRequestsOptions, options ...gitlab.RequestOptionFunc) (*gitlab.MergeRequest, *gitlab.Response, error)

GetMergeRequest provides a mock function with given fields: pid, mergeRequest, opt, options

func (*MergeRequestsService) ListMergeRequestPipelines

func (_m *MergeRequestsService) ListMergeRequestPipelines(pid interface{}, mergeRequest int, options ...gitlab.RequestOptionFunc) ([]*gitlab.PipelineInfo, *gitlab.Response, error)

ListMergeRequestPipelines provides a mock function with given fields: pid, mergeRequest, options

func (*MergeRequestsService) ListProjectMergeRequests

func (_m *MergeRequestsService) ListProjectMergeRequests(pid interface{}, opt *gitlab.ListProjectMergeRequestsOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.MergeRequest, *gitlab.Response, error)

ListProjectMergeRequests provides a mock function with given fields: pid, opt, options

type PipelinesService

type PipelinesService struct {
	mock.Mock
}

PipelinesService is an autogenerated mock type for the PipelinesService type

func NewPipelinesService

func NewPipelinesService(t interface {
	mock.TestingT
	Cleanup(func())
}) *PipelinesService

NewPipelinesService creates a new instance of PipelinesService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*PipelinesService) GetPipeline

func (_m *PipelinesService) GetPipeline(pid interface{}, pipeline int, options ...gitlab.RequestOptionFunc) (*gitlab.Pipeline, *gitlab.Response, error)

GetPipeline provides a mock function with given fields: pid, pipeline, options

func (*PipelinesService) ListProjectPipelines

func (_m *PipelinesService) ListProjectPipelines(pid interface{}, opt *gitlab.ListProjectPipelinesOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.PipelineInfo, *gitlab.Response, error)

ListProjectPipelines provides a mock function with given fields: pid, opt, options

type ProjectService

type ProjectService struct {
	mock.Mock
}

ProjectService is an autogenerated mock type for the ProjectService type

func NewProjectService

func NewProjectService(t interface {
	mock.TestingT
	Cleanup(func())
}) *ProjectService

NewProjectService creates a new instance of ProjectService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ProjectService) GetProject

func (_m *ProjectService) GetProject(pid interface{}, opt *gitlab.GetProjectOptions, options ...gitlab.RequestOptionFunc) (*gitlab.Project, *gitlab.Response, error)

GetProject provides a mock function with given fields: pid, opt, options

Jump to