mocks

package
v0.0.0-...-01ad037 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Jenkins

type Jenkins struct {
	mock.Mock
}

Jenkins is an autogenerated mock type for the Jenkins type

func NewJenkins

func NewJenkins(t interface {
	mock.TestingT
	Cleanup(func())
}) *Jenkins

NewJenkins creates a new instance of Jenkins. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Jenkins) GetBuildByJobId

func (_m *Jenkins) GetBuildByJobId(jobID string, number int) (gojenkins.Build, error)

GetBuildByJobId provides a mock function with given fields: jobID, number

func (*Jenkins) GetJob

func (_m *Jenkins) GetJob(jobName string) (gojenkins.Job, error)

GetJob provides a mock function with given fields: jobName

func (*Jenkins) GetLastBuildByJobId

func (_m *Jenkins) GetLastBuildByJobId(jobID string) (gojenkins.Build, error)

GetLastBuildByJobId provides a mock function with given fields: jobID

Jump to