package
Version:
v0.0.0-...-01ad037
Opens a new window with list of versions in this module.
Published: Aug 13, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func Byte(value, def byte) byte
-
func Duration(value, def time.Duration) time.Duration
-
func Float32(value, def float32) float32
-
func Float64(value, def float64) float64
-
func Int(value, def int) int
-
func Int16(value, def int16) int16
-
func Int32(value, def int32) int32
-
func Int64(value, def int64) int64
-
func Int8(value, def int8) int8
-
func Rune(value, def rune) rune
-
func String(value, def string) string
-
func Struct(value, def interface{}) interface{}
-
func Time(value, def time.Time) time.Time
-
func Uint(value, def uint) uint
-
func Uint16(value, def uint16) uint16
-
func Uint32(value, def uint32) uint32
-
func Uint64(value, def uint64) uint64
-
func Uint8(value, def uint8) uint8
-
func Uintptr(value, def uintptr) uintptr
Byte if value == byte zero value, return def otherwise return value
Duration if value == time.Duration zero value, return def otherwise return value
Float32 if value == float32 zero value, return def otherwise return value
Float64 if value == float64 zero value, return def otherwise return value
Int if value == int zero value, return def otherwise return value
Int16 if value == int16 zero value, return def otherwise return value
Int32 if value == int32 zero value, return def otherwise return value
Int64 if value == int64 zero value, return def otherwise return value
Int8 if value == int8 zero value, return def otherwise return value
Rune if value == rune zero value, return def otherwise return value
String if value == string zero value, return def otherwise return value
func Struct(value, def interface{}) interface{}
Struct if value == struct zero value, return def otherwise return value
Time if value == time.Time zero value, return def otherwise return value
Uint if value == uint zero value, return def otherwise return value
Uint16 if value == uint16 zero value, return def otherwise return value
Uint32 if value == uint32 zero value, return def otherwise return value
Uint64 if value == uint64 zero value, return def otherwise return value
Uint8 if value == uint8 zero value, return def otherwise return value
Uintptr if value == uintptr zero value, return def otherwise return value
Source Files
¶
Click to show internal directories.
Click to hide internal directories.