mocks

package
v0.0.0-...-01ad037 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GeneratorEnabler

type GeneratorEnabler struct {
	mock.Mock
}

GeneratorEnabler is an autogenerated mock type for the GeneratorEnabler type

func NewGeneratorEnabler

func NewGeneratorEnabler(t interface {
	mock.TestingT
	Cleanup(func())
}) *GeneratorEnabler

NewGeneratorEnabler creates a new instance of GeneratorEnabler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GeneratorEnabler) Enable

func (_m *GeneratorEnabler) Enable(variantName models.VariantName, generatorParamsValidator params.Validator, tileGeneratorFunction configmodels.TileGeneratorFunction)

Enable provides a mock function with given fields: variantName, generatorParamsValidator, tileGeneratorFunction

type Registry

type Registry struct {
	mock.Mock
}

Registry is an autogenerated mock type for the Registry type

func NewRegistry

func NewRegistry(t interface {
	mock.TestingT
	Cleanup(func())
}) *Registry

NewRegistry creates a new instance of Registry. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Registry) GetMonitorables

func (_m *Registry) GetMonitorables() []*registry.MonitorableMetadata

GetMonitorables provides a mock function with given fields:

func (*Registry) RegisterGenerator

func (_m *Registry) RegisterGenerator(generatedTileType models.TileType, minimalVersion versions.RawVersion, variantNames []models.VariantName) registry.GeneratorEnabler

RegisterGenerator provides a mock function with given fields: generatedTileType, minimalVersion, variantNames

func (*Registry) RegisterMonitorable

func (_m *Registry) RegisterMonitorable(monitorable models.Monitorable)

RegisterMonitorable provides a mock function with given fields: monitorable

func (*Registry) RegisterTile

func (_m *Registry) RegisterTile(tileType models.TileType, minimalVersion versions.RawVersion, variantNames []models.VariantName) registry.TileEnabler

RegisterTile provides a mock function with given fields: tileType, minimalVersion, variantNames

type TileEnabler

type TileEnabler struct {
	mock.Mock
}

TileEnabler is an autogenerated mock type for the TileEnabler type

func NewTileEnabler

func NewTileEnabler(t interface {
	mock.TestingT
	Cleanup(func())
}) *TileEnabler

NewTileEnabler creates a new instance of TileEnabler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*TileEnabler) Enable

func (_m *TileEnabler) Enable(variantName models.VariantName, paramsValidator params.Validator, routePath string)

Enable provides a mock function with given fields: variantName, paramsValidator, routePath

type TileMetadataExplorer

type TileMetadataExplorer struct {
	mock.Mock
}

TileMetadataExplorer is an autogenerated mock type for the TileMetadataExplorer type

func NewTileMetadataExplorer

func NewTileMetadataExplorer(t interface {
	mock.TestingT
	Cleanup(func())
}) *TileMetadataExplorer

NewTileMetadataExplorer creates a new instance of TileMetadataExplorer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*TileMetadataExplorer) GetMinimalVersion

func (_m *TileMetadataExplorer) GetMinimalVersion() versions.RawVersion

GetMinimalVersion provides a mock function with given fields:

func (*TileMetadataExplorer) GetVariant

GetVariant provides a mock function with given fields: variantName

func (*TileMetadataExplorer) GetVariantsNames

func (_m *TileMetadataExplorer) GetVariantsNames() []models.VariantName

GetVariantsNames provides a mock function with given fields:

type VariantMetadataExplorer

type VariantMetadataExplorer struct {
	mock.Mock
}

VariantMetadataExplorer is an autogenerated mock type for the VariantMetadataExplorer type

func NewVariantMetadataExplorer

func NewVariantMetadataExplorer(t interface {
	mock.TestingT
	Cleanup(func())
}) *VariantMetadataExplorer

NewVariantMetadataExplorer creates a new instance of VariantMetadataExplorer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*VariantMetadataExplorer) GetValidator

func (_m *VariantMetadataExplorer) GetValidator() params.Validator

GetValidator provides a mock function with given fields:

func (*VariantMetadataExplorer) IsEnabled

func (_m *VariantMetadataExplorer) IsEnabled() bool

IsEnabled provides a mock function with given fields:

Jump to