Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
Repository is an autogenerated mock type for the Repository type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) GetConfigFromPath ¶
GetConfigFromPath provides a mock function with given fields: baseDir, filePath
func (*Repository) GetConfigFromURL ¶
func (_m *Repository) GetConfigFromURL(url string) (*models.Config, error)
GetConfigFromURL provides a mock function with given fields: url
type Usecase ¶
Usecase is an autogenerated mock type for the Usecase type
func NewUsecase ¶
NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Usecase) GetConfig ¶
func (_m *Usecase) GetConfig(params *models.ConfigParams) *models.ConfigBag
GetConfig provides a mock function with given fields: params
func (*Usecase) GetConfigList ¶
func (_m *Usecase) GetConfigList() []models.ConfigMetadata
GetConfigList provides a mock function with given fields: