Documentation
¶
Index ¶
- type Repository
- func (_m *Repository) GetChecks(owner string, repository string, ref string) (*models.Checks, error)
- func (_m *Repository) GetCommit(owner string, repository string, sha string) (*models.Commit, error)
- func (_m *Repository) GetCount(query string) (int, error)
- func (_m *Repository) GetPullRequest(owner string, repository string, id int) (*models.PullRequest, error)
- func (_m *Repository) GetPullRequests(owner string, repository string) ([]models.PullRequest, error)
- type Usecase
- func (_m *Usecase) Checks(params *models.ChecksParams) (*monitorormodels.Tile, error)
- func (_m *Usecase) Count(params *models.CountParams) (*monitorormodels.Tile, error)
- func (_m *Usecase) PullRequest(params *models.PullRequestParams) (*monitorormodels.Tile, error)
- func (_m *Usecase) PullRequestsGenerator(params interface{}) ([]configmodels.GeneratedTile, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
Repository is an autogenerated mock type for the Repository type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) GetChecks ¶
func (_m *Repository) GetChecks(owner string, repository string, ref string) (*models.Checks, error)
GetChecks provides a mock function with given fields: owner, repository, ref
func (*Repository) GetCommit ¶
func (_m *Repository) GetCommit(owner string, repository string, sha string) (*models.Commit, error)
GetCommit provides a mock function with given fields: owner, repository, sha
func (*Repository) GetCount ¶
func (_m *Repository) GetCount(query string) (int, error)
GetCount provides a mock function with given fields: query
func (*Repository) GetPullRequest ¶
func (_m *Repository) GetPullRequest(owner string, repository string, id int) (*models.PullRequest, error)
GetPullRequest provides a mock function with given fields: owner, repository, id
func (*Repository) GetPullRequests ¶
func (_m *Repository) GetPullRequests(owner string, repository string) ([]models.PullRequest, error)
GetPullRequests provides a mock function with given fields: owner, repository
type Usecase ¶
Usecase is an autogenerated mock type for the Usecase type
func NewUsecase ¶
NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Usecase) Checks ¶
func (_m *Usecase) Checks(params *models.ChecksParams) (*monitorormodels.Tile, error)
Checks provides a mock function with given fields: params
func (*Usecase) Count ¶
func (_m *Usecase) Count(params *models.CountParams) (*monitorormodels.Tile, error)
Count provides a mock function with given fields: params
func (*Usecase) PullRequest ¶
func (_m *Usecase) PullRequest(params *models.PullRequestParams) (*monitorormodels.Tile, error)
PullRequest provides a mock function with given fields: params
func (*Usecase) PullRequestsGenerator ¶
func (_m *Usecase) PullRequestsGenerator(params interface{}) ([]configmodels.GeneratedTile, error)
PullRequestsGenerator provides a mock function with given fields: params