Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
Repository is an autogenerated mock type for the Repository type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) ExecutePing ¶
func (_m *Repository) ExecutePing(hostname string) (*models.Ping, error)
ExecutePing provides a mock function with given fields: hostname
type Usecase ¶
Usecase is an autogenerated mock type for the Usecase type
func NewUsecase ¶
NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Usecase) Ping ¶
func (_m *Usecase) Ping(params *models.PingParams) (*monitorormodels.Tile, error)
Ping provides a mock function with given fields: params