Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
Repository is an autogenerated mock type for the Repository type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) GetLastBuildStatus ¶
func (_m *Repository) GetLastBuildStatus(owner string, repository string, branch string) (*models.Build, error)
GetLastBuildStatus provides a mock function with given fields: owner, repository, branch
type Usecase ¶
Usecase is an autogenerated mock type for the Usecase type
func NewUsecase ¶
NewUsecase creates a new instance of Usecase. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Usecase) Build ¶
func (_m *Usecase) Build(params *models.BuildParams) (*monitorormodels.Tile, error)
Build provides a mock function with given fields: params