Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Jenkins ¶
Jenkins is an autogenerated mock type for the Jenkins type
func NewJenkins ¶
NewJenkins creates a new instance of Jenkins. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Jenkins) GetBuildByJobId ¶
GetBuildByJobId provides a mock function with given fields: jobID, number
Click to show internal directories.
Click to hide internal directories.